#
# spec file for package python-iniparse
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-iniparse
Version:        0.5
Release:        5.1
Summary:        Python Module for Accessing and Modifying Configuration Data in INI files
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/candlepin/python-iniparse
Source:         https://files.pythonhosted.org/packages/source/i/iniparse/iniparse-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: speilicke@suse.com -- Backport of https://code.google.com/p/iniparse/issues/detail?id=31
Patch0:         iniparse-insert-after-commented-option.patch
# https://github.com/candlepin/python-iniparse/commit/28dddd6f45fb5928d1477d14fac5daca92ffbb4c
Patch1:         python-iniparse-no-python2.patch
# https://github.com/candlepin/python-iniparse/commit/b3684a45d02af784d3d8f6ea680a351b38a865dc
Patch2:         python-iniparse-no-six.patch
# from https://github.com/candlepin/python-iniparse/pull/24
Patch3:         python311-compat.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# python2-devel contains test module, even for noarch package
BuildRequires:  %{python_module devel}
# tests require testsuite modules
BuildRequires:  %{python_module testsuite}
BuildArch:      noarch
%python_subpackages

%description
iniparse is an INI parser for Python which is API compatible with the
standard library's ConfigParser, preserves structure of INI files
(order of sections & options, indentation, comments, and blank lines
are preserved when data is updated), and is more convenient to use.

%prep
%setup -q -n iniparse-%{version}
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1

chmod 644 html/index.html
sed -i "/.*test_multiprocessing.*/d" tests/__init__.py # NOTE(saschpe): Doesn't work and I'm lazy

%build
%python_build

%install
%python_install
rm -rf %{buildroot}%{_datadir}/doc/iniparse-%{version} # Remove unwanted stuff
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec runtests.py -v

%files %{python_files}
%license LICENSE
%doc Changelog LICENSE-PSF README.md html/*
%{python_sitelib}/iniparse
%{python_sitelib}/iniparse-*.egg-info

%changelog
* Mon Aug 14 2023 Dirk Müller <dmueller@suse.com>
- add python311-compat.patch to fix build with python 3.11/12
* Mon Nov  7 2022 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://github.com/candlepin/python-iniparse/commit/28dddd6f45fb5928d1477d14fac5daca92ffbb4c
  + python-iniparse-no-python2.patch
  fix https://github.com/candlepin/python-iniparse/commit/b3684a45d02af784d3d8f6ea680a351b38a865dc
  + python-iniparse-no-six.patch
* Wed Mar  2 2022 Matej Cepl <mcepl@suse.com>
- Fix BR: it is %%{python_module devel} not python2-devel.
* Thu Oct 29 2020 Benjamin Greiner <code@bnavigator.de>
- Need python3X-testsuite for all flavors
  (see gh#openSUSE/python-rpm-macros#66)
* Tue Apr 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.5
  * upstream changed
  * code improvements
  * Python 3 support
- Reapplied patch iniparse-insert-after-commented-option.patch
- Dropped upstreamed patches:
  * iniparse-fix-issue-28.patch
  * python-iniparse-python3-compat.patch
  * python-iniparse-setup-fixes.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov 14 2017 jmatejek@suse.com
- require %%{python_module devel} instead of listing the devels one by one
* Thu Sep 14 2017 ngompa13@gmail.com
- Add missing python-six runtime dependency
* Tue Jun  6 2017 ngompa13@gmail.com
- Add patches from Fedora to enable Python 3 support
  * iniparse-fix-issue-28.patch
  * python-iniparse-python3-compat.patch
  * python-iniparse-setup-fixes.patch
- Convert to singlespec to offer Python 3 variant
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon May 27 2013 speilicke@suse.com
- Add iniparse-insert-after-commented-option.patch: See
  https://code.google.com/p/iniparse/issues/detail?id=31 for details
- Run testsuite
* Thu Feb 23 2012 berendt@b1-systems.de
- added missing build requirement python-devel for SLE
* Tue Jan 31 2012 saschpe@suse.de
- Spec file cleanup:
  * Simplified macro usage
  * Removed outdated %%clean section
  * Buildrequire python-distribute instead of setuptools
* Thu Sep 16 2010 coolo@novell.com
- update to 0.4
  * Fixed pickling and multiprocessing bugs
  * Enabled auto-addition of config attributes via square bracket
    syntax
  * Utility function to tidy INI files
  * Ability to change comment syntax for parsing Mercurial config
    files
  * Added ConfigParser exceptions and constants to the top-level
    iniparse module
* Wed Aug  5 2009 matejcik@suse.cz
- update to 0.3.1
  * minor bugfixes
  * better multi-line handling
* Wed Jan  7 2009 cthiel@suse.de
- initial package (version 0.2.4)
